__version__ = "0.1.0"

"""
1. Initiation step.

2. Add initial data

3. add single field 

4. send data to REST API

"""


from sleepwell.event import Event
from sleepwell import state


def init(url=""):
    state.URL = url


def new_event(data={}):
    return Event(data=data)


__all__ = ["new_event"]



import datetime
import json
import uuid


class JSONEncoder(json.JSONEncoder):
    """
    JSONEncoder subclass that knows how to encode date/time/timedelta,
    and UUID

    """

    def default(self, obj):
        if isinstance(obj, datetime.datetime):
            render = obj.isoformat()
            if render.endswith("+00:00"):
                render = render[:-6] + "Z"
            return render
        elif isinstance(obj, datetime.date):
            return obj.isoformat()
        elif isinstance(obj, datetime.timedelta):
            return str(obj.total_seconds())
        elif isinstance(obj, uuid.UUID):
            return str(obj)
        return super().default(obj)



"""
define the event objects 

format data to be sent 
"""
import json
import requests
from sleepwell import state
from sleepwell.utils import JSONEncoder


class Event:
    """

    Event class for recording events to be sent on Sleep well API

    """

    def __init__(self, data={}):
        self._data = data

    def add_field(self, key, value):
        self._data[key] = value

    def add(self, data):
        try:
            for k, v in data.items():
                self.add_field(k, v)

        except AttributeError:
            raise TypeError("add requires a dict-like argument")

    def is_empty(self):
        return len(self._data) == 0

    def __str__(self):
        return json.dumps(self._data, sort_keys=True, indent=1, cls=JSONEncoder)

    def send(self):
        if state.URL == None:
            return Exception("No url provided")

        requests.post(
            state.URL,
            headers={"Content-type": "application/json"},
            data=json.dumps(self._data, sort_keys=True, indent=1, cls=JSONEncoder),
        )
